@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Test markdown and text widgets."""
 
 import time
@@ -14,11 +13,10 @@ reset_uuid()
 
 # pylint: disable=invalid-name
 button = Button()
-store = {}
 
 
 def click():
-    """Update markdown text."""
+    """Save and load cache."""
     cache['a'] = 3
     assert cache[b'a'] == 3
     assert cache[u'a'] == 3
@@ -41,7 +39,7 @@ def test_keys():
 
 @pytest.fixture
 def dummy(build_path, monkeypatch):
-    """Create markdown and text widgets."""
+    """Create basic app."""
     monkeypatch.setattr(App, '_sourcefile', lambda self: 'bowtie.tests.test_cache')
 
     app = App()
@@ -56,7 +54,7 @@ def dummy(build_path, monkeypatch):
 
 # pylint: disable=redefined-outer-name,unused-argument
 def test_cache(dummy, chrome_driver):
-    """Test markdown and text widgets."""
+    """Test cache works."""
     chrome_driver.get('http://localhost:9991')
     chrome_driver.implicitly_wait(5)
 
