@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Utility functions for testing only."""
 
 import os
@@ -8,6 +7,7 @@ from contextlib import contextmanager
 from subprocess import Popen, PIPE
 import time
 
+from bowtie import View
 from bowtie._component import Component
 
 
@@ -15,6 +15,7 @@ def reset_uuid():
     """Reset the uuid counter for components."""
     # pylint: disable=protected-access
     Component._NEXT_UUID = 0
+    View._NEXT_UUID = 0
 
 
 @contextmanager
